@@ -300,6 +300,102 @@ class TestCreateCocoDatasetManifest(unittest.TestCase):
             self.assertEqual(dataset_manifest.images[0].labels, [[0, 10, 10, 100, 100]])
             self.assertEqual(dataset_manifest.images[1].labels, [[0, 100, 100, 200, 200], [1, 20, 20, 200, 200]])
 
+    def test_image_caption(self):
+        manifest_dict = {
+            "images": [{"id": 1, "file_name": "train_images.zip@honda.jpg"},
+                       {"id": 2, "file_name": "train_images.zip@kitchen.jpg"}],
+            "annotations": [
+                {"id": 1, "image_id": 1, "caption": "A black Honda motorcycle parked in front of a garage."},
+                {"id": 2, "image_id": 1, "caption": "A Honda motorcycle parked in a grass driveway."},
+                {"id": 3, "image_id": 1, "caption": "A black Honda motorcycle with a dark burgundy seat."},
+                {"id": 4, "image_id": 1, "caption": "Ma motorcycle parked on the gravel in front of a garage."},
+                {"id": 5, "image_id": 1, "caption": "A motorcycle with its brake extended standing outside."},
+                {"id": 6, "image_id": 2, "caption": "A picture of a modern looking kitchen area.\n"},
+                {"id": 7, "image_id": 2, "caption": "A narrow kitchen ending with a chrome refrigerator."},
+                {"id": 8, "image_id": 2, "caption": "A narrow kitchen is decorated in shades of white, gray, and black."},
+                {"id": 9, "image_id": 2, "caption": "a room that has a stove and a icebox in it"},
+                {"id": 10, "image_id": 2, "caption": "A long empty, minimal modern skylit home kitchen."}
+            ],
+        }
+        caption_1 = ['A black Honda motorcycle parked in front of a garage.',
+                     'A Honda motorcycle parked in a grass driveway.',
+                     'A black Honda motorcycle with a dark burgundy seat.',
+                     'Ma motorcycle parked on the gravel in front of a garage.',
+                     'A motorcycle with its brake extended standing outside.']
+        caption_2 = ['A picture of a modern looking kitchen area.\n',
+                     'A narrow kitchen ending with a chrome refrigerator.',
+                     'A narrow kitchen is decorated in shades of white, gray, and black.',
+                     'a room that has a stove and a icebox in it',
+                     'A long empty, minimal modern skylit home kitchen.']
+
+        dataset_dict = copy.deepcopy(self.DATASET_INFO_DICT)
+        with tempfile.TemporaryDirectory() as tempdir:
+            dataset_dict['root_folder'] = ''
+            dataset_dict['type'] = 'image_caption'
+            coco_file_path = os.path.join(tempdir, 'test.json')
+            with open(coco_file_path, 'w') as f:
+                json.dump(manifest_dict, f)
+            dataset_manifest = CocoManifestAdaptor.create_dataset_manifest(coco_file_path, DatasetTypes.IMCAP)
+            self.assertIsInstance(dataset_manifest, DatasetManifest)
+            self.assertEqual(len(dataset_manifest.images), 2)
+            self.assertEqual(dataset_manifest.images[0].labels, caption_1)
+            self.assertEqual(dataset_manifest.images[1].labels, caption_2)
+
+    def test_multitask_ic_multilabel_and_image_caption(self):
+        classfication_manifest_dict = {
+            "images": [{"id": 1, "width": 224.0, "height": 224.0, "file_name": "siberian-kitten.jpg"},
+                       {"id": 2, "width": 224.0, "height": 224.0, "file_name": "kitten 3.jpg"}],
+            "annotations": [
+                {"id": 1, "category_id": 1, "image_id": 1},
+                {"id": 2, "category_id": 1, "image_id": 2},
+                {"id": 3, "category_id": 2, "image_id": 2}
+            ], "categories": [{"id": 1, "name": "cat"}, {"id": 2, "name": "dog"}]
+        }
+        imcap_manifest_dict = {
+            "images": [{"id": 1, "file_name": "train_images.zip@honda.jpg"},
+                       {"id": 2, "file_name": "train_images.zip@kitchen.jpg"}],
+            "annotations": [
+                {"id": 1, "image_id": 1, "caption": "A black Honda motorcycle parked in front of a garage."},
+                {"id": 2, "image_id": 1, "caption": "A Honda motorcycle parked in a grass driveway."},
+                {"id": 3, "image_id": 1, "caption": "A black Honda motorcycle with a dark burgundy seat."},
+                {"id": 4, "image_id": 1, "caption": "Ma motorcycle parked on the gravel in front of a garage."},
+                {"id": 5, "image_id": 1, "caption": "A motorcycle with its brake extended standing outside."},
+                {"id": 6, "image_id": 2, "caption": "A picture of a modern looking kitchen area.\n"},
+                {"id": 7, "image_id": 2, "caption": "A narrow kitchen ending with a chrome refrigerator."},
+                {"id": 8, "image_id": 2, "caption": "A narrow kitchen is decorated in shades of white, gray, and black."},
+                {"id": 9, "image_id": 2, "caption": "a room that has a stove and a icebox in it"},
+                {"id": 10, "image_id": 2, "caption": "A long empty, minimal modern skylit home kitchen."}
+            ],
+        }
+        caption_1 = ['A black Honda motorcycle parked in front of a garage.',
+                     'A Honda motorcycle parked in a grass driveway.',
+                     'A black Honda motorcycle with a dark burgundy seat.',
+                     'Ma motorcycle parked on the gravel in front of a garage.',
+                     'A motorcycle with its brake extended standing outside.']
+        caption_2 = ['A picture of a modern looking kitchen area.\n',
+                     'A narrow kitchen ending with a chrome refrigerator.',
+                     'A narrow kitchen is decorated in shades of white, gray, and black.',
+                     'a room that has a stove and a icebox in it',
+                     'A long empty, minimal modern skylit home kitchen.']
+
+        dataset_dict = copy.deepcopy(self.DATASET_INFO_DICT)
+        with tempfile.TemporaryDirectory() as tempdir:
+            dataset_dict['root_folder'] = ''
+            dataset_dict['type'] = {'task1': DatasetTypes.IC_MULTILABEL, 'task2': DatasetTypes.IMCAP}
+            classification_coco_file_path = os.path.join(tempdir, 'classification_test.json')
+            with open(classification_coco_file_path, 'w') as f:
+                json.dump(classfication_manifest_dict, f)
+            imcap_coco_file_path = os.path.join(tempdir, 'imcap_test.json')
+            with open(imcap_coco_file_path, 'w') as f:
+                json.dump(imcap_manifest_dict, f)
+            coco_file_path = {'task1': classification_coco_file_path, 'task2': imcap_coco_file_path}
+            dataset_manifest = CocoManifestAdaptor.create_dataset_manifest(coco_file_path, dataset_dict['type'])
+            self.assertIsInstance(dataset_manifest, DatasetManifest)
+            self.assertEqual(len(dataset_manifest.images), 2)
+            self.assertEqual(len(dataset_manifest.labelmap), 2)
+            self.assertEqual(dataset_manifest.images[0].labels, {'task1': [0], 'task2': caption_1})
+            self.assertEqual(dataset_manifest.images[1].labels, {'task1': [0, 1], 'task2': caption_2})
+
 
 class TestManifestFewShotSample(unittest.TestCase):
     def test_multiclass_sample_10_out_of_30(self):
